@@ -165,6 +165,10 @@ void WINAPI vpb_translate_event(VPB_EVENT *e, char s[])
 					((e->data)==0 ? "NEG":"POS"));
 		break;
 
+		case VPB_LOOP_FLASH:
+			sprintf(s, "[%02d] Loop Hook FLASH\n",e->handle);
+		break;
+
 		case VPB_ISDN_BUSY:
 			sprintf(s, "[%02d] ISDN busy\n",e->handle);
 		break;
