@@ -97,15 +97,99 @@ bool SetProcfsInfo(const char *node, const char *value, size_t len);
 } //}}}
 #endif
 
-/* internal function defns */
-static void trim_buffer(char * buffer);
-static int conf_get_section(char * buffer);
-static int conf_save_buf(int file_type, CONF_INFO * conf_pointer, int state,
-			 int sect, int subsect, int cardno, char *buffer);
-static int conf_get_tag_value(char * tag,char * value,char * buffer);
-static int conf_get_cardno(char * buffer);
-static void conf_dump_print(CONF_INFO * conf_p);
 
+static void conf_dump_print(CONF_INFO *conf_p)
+{ //{{{
+	int x,z;
+
+	mprintf("=================== GENERAL ========================\n");
+	mprintf("Country code [%d]\n",conf_p->country_code);
+	mprintf("Tone count[%d]\n",conf_p->tone_count);
+	if (conf_p->tone_count > 0){
+		for(int i=0; i < conf_p->tone_count; ++i){
+			mprintf("\t Tone [%d]:\n",i);
+			mprintf("\t\t Defn [%s]\n",conf_p->tones[i].defn);
+			mprintf("\t\t Type [%s]\n",conf_p->tones[i].type);
+			mprintf("\t\t Freq1 [%d]\n",conf_p->tones[i].freq1);
+			mprintf("\t\t Band1 [%d]\n",conf_p->tones[i].band1);
+			mprintf("\t\t Time On [%d]\n",conf_p->tones[i].ton);
+			mprintf("\t\t Time Off [%d]\n",conf_p->tones[i].toff);
+			mprintf("\t\t Freq2 [%d]\n",conf_p->tones[i].freq2);
+			mprintf("\t\t Band2 [%d]\n",conf_p->tones[i].band2);
+			mprintf("\t\t snr [%d]\n",conf_p->tones[i].snr);
+			mprintf("\t\t twist [%d]\n",conf_p->tones[i].twist);
+		}
+	}
+	mprintf("Card Count[%d]\n",conf_p->cardcount);
+	if (conf_p->cardcount > 0 ){
+		for(unsigned int i=0; i < conf_p->cardcount && i < 254; ++i){
+			mprintf("\tCard[%d] type[%d] number[%d]\n", i,
+				conf_p->cards[i].type, conf_p->cards[i].number);
+		}
+	}
+	mprintf("=================== OpenPRI ========================\n");
+	mprintf("Channels [%d]\n",conf_p->OpenPri.channels);
+	mprintf("Cards [%d]\n",conf_p->OpenPri.cards);
+	for (x=0;x<conf_p->OpenPri.cards;x++){
+		mprintf("\tCard Num [%d]\n",x);
+		mprintf("\tInterface type [%d]\n",conf_p->OpenPri.card[x].if_type);
+		mprintf("\tNode type [%d]\n",conf_p->OpenPri.card[x].node);
+		mprintf("\tD-channel [%d]\n",conf_p->OpenPri.card[x].d_channel);
+		z=(conf_p->OpenPri.card[x].if_type == VPB_PRI_E1?31:24);
+		for(int i=1; i <= z; ++i){
+			mprintf("\t Channel Num[%d]\n",i);
+			mprintf("\t\t Channel [%d]\n",
+				conf_p->OpenPri.card[x].iface[i].channel);
+			mprintf("\t\t Channel Name [%s]\n",
+				conf_p->OpenPri.card[x].iface[i].name);
+			mprintf("\t\t Card Name [%s]\n",
+				conf_p->OpenPri.card[x].iface[i].card);
+			mprintf("\t\t Encoding [%s]\n",
+				(VPB_ALAW == conf_p->OpenPri.card[x].iface[i].encoding
+				    ? "alaw"
+				    : (VPB_MULAW == conf_p->OpenPri.card[x].iface[i].encoding
+					? "ulaw" : "raw")));
+		}
+	}
+	mprintf("=================== OpenLine =======================\n");
+	mprintf("Channels [%d]\n",conf_p->OpenLine.cards * 4);
+	mprintf("Cards [%d]\n",conf_p->OpenLine.cards);
+	for (x=0;x<conf_p->OpenLine.cards;x++){
+		mprintf("\tCard Num [%d]\n",conf_p->OpenLine.card[x].cardnum);
+		mprintf("\tCard type [%d]\n",conf_p->OpenLine.card[x].type);
+		mprintf("\tCard channels [4]\n");
+		for(int i=0; i < 4; ++i) {
+			mprintf("\t\tChannel [%d]\n", i);
+			mprintf("\t\tType [%d]\n", VPB_FXO);
+			mprintf("\t\tSettings [%d]\n",
+				conf_p->OpenLine.card[x].iface[i].settings);
+			if (conf_p->OpenLine.card[x].iface[i].settings & MOD_HWPG){
+				mprintf("\t\t\tHW Play Gain [%f]\n",
+					conf_p->OpenLine.card[x].iface[i].hw_play_gain);
+			}
+			if (conf_p->OpenLine.card[x].iface[i].settings & MOD_HWRG){
+				mprintf("\t\t\tHW Record Gain [%f]\n",
+					conf_p->OpenLine.card[x].iface[i].hw_rec_gain);
+			}
+			if (conf_p->OpenLine.card[x].iface[i].settings & MOD_PG){
+				mprintf("\t\t\tPlay Gain [%f]\n",
+					conf_p->OpenLine.card[x].iface[i].play_gain);
+			}
+			if (conf_p->OpenLine.card[x].iface[i].settings & MOD_RG){
+				mprintf("\t\t\tRecord Gain [%f]\n",
+					conf_p->OpenLine.card[x].iface[i].rec_gain);
+			}
+			if (conf_p->OpenLine.card[x].iface[i].settings & MOD_BALS){
+				mprintf("\t\t\tBal1[0x%x]\n",
+					conf_p->OpenLine.card[x].iface[i].codec_hyb_bal1);
+				mprintf("\t\t\tBal2[0x%x]\n",
+					conf_p->OpenLine.card[x].iface[i].codec_hyb_bal2);
+				mprintf("\t\t\tBal3[0x%x]\n",
+					conf_p->OpenLine.card[x].iface[i].codec_hyb_bal3);
+			}
+		}
+	}
+} //}}}
 
 llc_list *vpb_read_confll(CONF_INFO *cp)
 { //{{{
@@ -323,7 +407,10 @@ llc_list *vpb_read_confll(CONF_INFO *cp)
 						settings |= MOD_RG;
 					}
 					else if(strcasecmp(var->name,"name")==0){
-						strcpy((char *)cp->OpenPri.card[i].name,var->value);
+						char *c = (char*)cp->OpenPri.card[i].name;
+
+						strncpy(c, var->value, OPRI_NAME_LEN - 1);
+						c[OPRI_NAME_LEN - 1] = '\0';
 					}
 					else if(strcasecmp(var->name,"iftype")==0){
 						if (strcasecmp(var->value,"e1")==0){
@@ -505,6 +592,20 @@ llc_list *vpb_read_confll(CONF_INFO *cp)
 	return list_root;
 } //}}}
 
+
+//XXX Old and unused.
+#if 0
+//{{{
+
+/* internal function defns */
+static void trim_buffer(char * buffer);
+static int conf_get_section(char * buffer);
+static int conf_save_buf(int file_type, CONF_INFO * conf_pointer, int state,
+			 int sect, int subsect, int cardno, char *buffer);
+static int conf_get_tag_value(char * tag,char * value,char * buffer);
+static int conf_get_cardno(char * buffer);
+
+
 /******************************************************************************
 	FUNC: vpb_read_conf
 	DESC: Reads a conf file in to the conf_info structure pointer passed
@@ -918,98 +1019,8 @@ int conf_get_tag_value(char * tag,char * value,char * buffer)
 	}
 }
 
-void conf_dump_print(CONF_INFO *conf_p)
-{ //{{{
-	int x,z;
-
-	mprintf("=================== GENERAL ========================\n");
-	mprintf("Country code [%d]\n",conf_p->country_code);
-	mprintf("Tone count[%d]\n",conf_p->tone_count);
-	if (conf_p->tone_count > 0){
-		for(int i=0; i < conf_p->tone_count; ++i){
-			mprintf("\t Tone [%d]:\n",i);
-			mprintf("\t\t Defn [%s]\n",conf_p->tones[i].defn);
-			mprintf("\t\t Type [%s]\n",conf_p->tones[i].type);
-			mprintf("\t\t Freq1 [%d]\n",conf_p->tones[i].freq1);
-			mprintf("\t\t Band1 [%d]\n",conf_p->tones[i].band1);
-			mprintf("\t\t Time On [%d]\n",conf_p->tones[i].ton);
-			mprintf("\t\t Time Off [%d]\n",conf_p->tones[i].toff);
-			mprintf("\t\t Freq2 [%d]\n",conf_p->tones[i].freq2);
-			mprintf("\t\t Band2 [%d]\n",conf_p->tones[i].band2);
-			mprintf("\t\t snr [%d]\n",conf_p->tones[i].snr);
-			mprintf("\t\t twist [%d]\n",conf_p->tones[i].twist);
-		}
-	}
-	mprintf("Card Count[%d]\n",conf_p->cardcount);
-	if (conf_p->cardcount > 0 ){
-		for(unsigned int i=0; i < conf_p->cardcount && i < 254; ++i){
-			mprintf("\tCard[%d] type[%d] number[%d]\n", i,
-				conf_p->cards[i].type, conf_p->cards[i].number);
-		}
-	}
-	mprintf("=================== OpenPRI ========================\n");
-	mprintf("Channels [%d]\n",conf_p->OpenPri.channels);
-	mprintf("Cards [%d]\n",conf_p->OpenPri.cards);
-	for (x=0;x<conf_p->OpenPri.cards;x++){
-		mprintf("\tCard Num [%d]\n",x);
-		mprintf("\tInterface type [%d]\n",conf_p->OpenPri.card[x].if_type);
-		mprintf("\tNode type [%d]\n",conf_p->OpenPri.card[x].node);
-		mprintf("\tD-channel [%d]\n",conf_p->OpenPri.card[x].d_channel);
-		z=(conf_p->OpenPri.card[x].if_type == VPB_PRI_E1?31:24);
-		for(int i=1; i <= z; ++i){
-			mprintf("\t Channel Num[%d]\n",i);
-			mprintf("\t\t Channel [%d]\n",
-				conf_p->OpenPri.card[x].iface[i].channel);
-			mprintf("\t\t Channel Name [%s]\n",
-				conf_p->OpenPri.card[x].iface[i].name);
-			mprintf("\t\t Card Name [%s]\n",
-				conf_p->OpenPri.card[x].iface[i].card);
-			mprintf("\t\t Encoding [%s]\n",
-				(VPB_ALAW == conf_p->OpenPri.card[x].iface[i].encoding
-				    ? "alaw"
-				    : (VPB_MULAW == conf_p->OpenPri.card[x].iface[i].encoding
-					? "ulaw" : "raw")));
-		}
-	}
-	mprintf("=================== OpenLine =======================\n");
-	mprintf("Channels [%d]\n",conf_p->OpenLine.cards * 4);
-	mprintf("Cards [%d]\n",conf_p->OpenLine.cards);
-	for (x=0;x<conf_p->OpenLine.cards;x++){
-		mprintf("\tCard Num [%d]\n",conf_p->OpenLine.card[x].cardnum);
-		mprintf("\tCard type [%d]\n",conf_p->OpenLine.card[x].type);
-		mprintf("\tCard channels [4]\n");
-		for(int i=0; i < 4; ++i) {
-			mprintf("\t\tChannel [%d]\n", i);
-			mprintf("\t\tType [%d]\n", VPB_FXO);
-			mprintf("\t\tSettings [%d]\n",
-				conf_p->OpenLine.card[x].iface[i].settings);
-			if (conf_p->OpenLine.card[x].iface[i].settings & MOD_HWPG){
-				mprintf("\t\t\tHW Play Gain [%f]\n",
-					conf_p->OpenLine.card[x].iface[i].hw_play_gain);
-			}
-			if (conf_p->OpenLine.card[x].iface[i].settings & MOD_HWRG){
-				mprintf("\t\t\tHW Record Gain [%f]\n",
-					conf_p->OpenLine.card[x].iface[i].hw_rec_gain);
-			}
-			if (conf_p->OpenLine.card[x].iface[i].settings & MOD_PG){
-				mprintf("\t\t\tPlay Gain [%f]\n",
-					conf_p->OpenLine.card[x].iface[i].play_gain);
-			}
-			if (conf_p->OpenLine.card[x].iface[i].settings & MOD_RG){
-				mprintf("\t\t\tRecord Gain [%f]\n",
-					conf_p->OpenLine.card[x].iface[i].rec_gain);
-			}
-			if (conf_p->OpenLine.card[x].iface[i].settings & MOD_BALS){
-				mprintf("\t\t\tBal1[0x%x]\n",
-					conf_p->OpenLine.card[x].iface[i].codec_hyb_bal1);
-				mprintf("\t\t\tBal2[0x%x]\n",
-					conf_p->OpenLine.card[x].iface[i].codec_hyb_bal2);
-				mprintf("\t\t\tBal3[0x%x]\n",
-					conf_p->OpenLine.card[x].iface[i].codec_hyb_bal3);
-			}
-		}
-	}
-} //}}}
+//}}}
+#endif
 
 #if 0
 void conf_dumper(CONF_INFO * conf_p)
