@@ -36,7 +36,12 @@
 
 // This was moved out of version.h around 2.6.18
 #ifndef UTS_RELEASE
-#include <linux/utsrelease.h>
+ // and then moved again out of include/linux after 2.6.32
+ #if (LINUX_VERSION_CODE > KERNEL_VERSION(2,6,32))
+  #include <generated/utsrelease.h>
+ #else
+  #include <linux/utsrelease.h>
+ #endif
 #endif
 
 #ifdef MODVERSIONS
