@@ -1030,7 +1030,7 @@ int proc_read_country(char *page, char **start, off_t off, int count, int *eof,
 int proc_write_country(struct file *file, const char *buffer, unsigned long count, void *data)
 { //{{{
 	struct vtboard *board;
-	char    buf[16] = { [0 ... 15] = 0 };
+	char    buf[16] = { 0 };
 	char   *b = buf;
 	int     ret;
 
@@ -1084,7 +1084,7 @@ int proc_write_##attrib(struct file *file, const char *buffer,		    \
 {									    \
 	struct vtboard *board;						    \
 	long    val;							    \
-	char    buf[8] = { [0 ... 7] = 0 };				    \
+	char    buf[8] = { 0 };						    \
 	char   *end;							    \
 	int     ret;							    \
 									    \
@@ -1320,7 +1320,7 @@ int vt_board_register(struct vtboard *board)
 	vtcore->boards[i] = board;
 
 	if( vtcore->procfs_root ) { //{{{
-		char  dirname[8] = { [0 ... 7] = 0 };
+		char  dirname[8] = { 0 };
 
 		snprintf(dirname, sizeof(dirname)-1, "board%d", i);
 		board->procfs_root = proc_mkdir(dirname, vtcore->procfs_root);
@@ -1411,7 +1411,7 @@ int vt_board_register(struct vtboard *board)
 
 
 		if( board->procfs_root ){ //{{{
-			char  dirname[8] = { [0 ... 7] = 0 };
+			char  dirname[8] = { 0 };
 
 			snprintf(dirname, sizeof(dirname)-1, "port%d", i);
 			chan->procfs_root = proc_mkdir(dirname, board->procfs_root);
@@ -1544,7 +1544,7 @@ void vt_board_unregister(struct vtboard *board)
 						 MINOR(board->tap_dev) + i ) );
 
 		if( chan->procfs_root ) {
-			char  dirname[8] = { [0 ... 7] = 0 };
+			char  dirname[8] = { 0 };
 
 			snprintf(dirname, sizeof(dirname)-1, "port%d", i);
 			remove_proc_entry("type", chan->procfs_root);
@@ -1566,7 +1566,7 @@ void vt_board_unregister(struct vtboard *board)
 	}
 
 	if( board->procfs_root ){
-		char  dirname[8] = { [0 ... 7] = 0 };
+		char  dirname[8] = { 0 };
 
 		snprintf(dirname, sizeof(dirname)-1, "board%d", board->boardnum);
 		remove_proc_entry("name", board->procfs_root);
